/*
 * shadowircd: an advanced internet relay chat daemon(ircd)
 * sendraw.c: Sends a client a raw message. Why? We don't know.
 *
 * ShadowIRCd is free software; for licensing details, see the LICENSE
 * file in the source tree.
 *
 * $Id: sendraw.c,v 1.1.2.3 2004/11/08 23:43:30 nenolod Exp $
 */
#include "stdinc.h"
#include "client.h"
#include "send.h"
#include "modules.h"
#include "handlers.h"
#include "numeric.h"
#include "hash.h"
#include "irc_string.h"
#include "umodes.h"

static void mo_sendraw(struct Client *client_p, struct Client *source_p,
                    int parc, char *parv[]);

struct Message sendraw_msgtab = {
	"SENDRAW", 0, 0, 1, 0, MFLG_SLOW, 0,
	{m_ignore, m_ignore, m_ignore, mo_sendraw, m_ignore}
};

#ifndef STATIC_MODULES
void
_modinit(void)
{
	mod_add_cmd(&sendraw_msgtab);
}

void
_moddeinit(void)
{
	mod_del_cmd(&sendraw_msgtab);
}

const char *_version = "$Revision: 1.1.2.3 $";
#endif

/*
 * mo_sendraw:
 *
 * Syntax: /sendraw [nick] :[string]
 *
 * The string is prefixed with a :.
 */
static void mo_sendraw(struct Client *client_p, struct Client *source_p,
                   int parc, char *parv[])
{		 
	struct Client *target_p;

	target_p = find_client(parv[1]);

	if (!target_p)
	{
		sendto_one(source_p, form_str(ERR_NOSUCHNICK),
			me.name, source_p->name, parv[1]);
		return;
	}

	if (!MyClient(target_p))
	{
		sendto_one(source_p, ":%s NOTICE %s :You can only SENDRAW to local clients!",
				me.name, source_p->name);
		return;
	}

	if (parv[2])
		sendto_one(target_p, ":%s", parv[2]);

	sendto_wallops_flags(UMODE_OPERWALL, &me, "%s is using SENDRAW against %s (string :%s)",
				source_p->name, target_p->name, parv[2]);

	return;
}
